@@ -1,4 +1,6 @@
 from typing import List, Dict, Any
+import os
+from audiodotturn import VERSION
 from audiodotturn.config import ConfigUser
 from audiodotturn.construct import Constructor
 from audiodotturn.extract import Extractor
@@ -12,6 +14,19 @@ class AudioDotTurn:
         self.database = Database(db_path or self.config.db_path)
         self.current_data = None
         self.constructor = None
+    
+    def settings_dict(self):
+        settings = {
+            "audiodoturn": VERSION,
+            "config path": self.config.config_path,
+            "db path": self.config.db_path,
+            "constructors": self.config.constructors,
+            "exts": self.config.exts,
+            "output options": self.config.output_opts,
+            "dry run": self.config.dry
+        }
+
+        return settings
 
     def extract_files(self, files: List[str], output_format: str = "dict") -> List[Any]:
         """
@@ -30,6 +45,17 @@ class AudioDotTurn:
         self.current_data = self.extractor.get_extraction(opt)
         return [self.current_data]
 
+    def files_in_dir(self, directory: str):
+        try:
+            files = [file for file in os.listdir(directory) if os.path.isfile(os.path.join(directory, file)) and file.endswith(tuple(self.config.exts))]
+        except Exception as error:
+            raise NotADirectoryError("Issue getting files from directory")
+
+        if not files:
+            raise UserWarning("Directory doesn't seem to contain any files with valid filename extensions.")
+
+        return files
+
     def update_database(self, data: List[Dict] = None) -> None:
         """
         Updates the database with data extracted from audio files.
